@@ -13,10 +13,13 @@ class Review(models.Model):
     url = models.URLField(blank=True)
     body = RichTextField()
 
+    class Meta:
+        db_table='plicata_reviews_reviews'
+
 class Quote(models.Model):
     review = models.ForeignKey(Review)
     visible = models.BooleanField(default=True)
     sortorder = models.IntegerField(default=999)
     quote = RichTextField()
-
-#test
\ No newline at end of file
+    class Meta:
+        db_table='plicata_reviews_quotes'
